@@ -45,38 +45,44 @@ sub load {
     my $class = shift;
     my $file  = shift;
 
-    open( my $fh, $file ) or die $!;
+    open( my $fh, '<', $file ) or die $!;
+    binmode $fh;
     my $content = do { local $/; <$fh> };
     close $fh;
 
-    eval { require JSON::DWIW; };
-    unless( $@ ) {
+    if ( eval { require Cpanel::JSON::XS } ) {
+        my $decoder = Cpanel::JSON::XS->new->utf8->relaxed;
+        return $decoder->decode( $content );
+    }
+    elsif ( eval { require JSON::MaybeXS } ) {
+        my $decoder = JSON::MaybeXS::JSON()->new->utf8->relaxed;
+        return $decoder->decode( $content );
+    }
+    elsif ( eval { require JSON::DWIW } ) {
         my $decoder = JSON::DWIW->new;
         my ( $data, $error ) = $decoder->from_json( $content );
         die $error if $error;
         return $data;
     }
-
-    eval { require JSON::XS; };
-    unless( $@ ) {
-        my $decoder = JSON::XS->new->relaxed;
+    elsif ( eval { require JSON::XS } ) {
+        my $decoder = JSON::XS->new->utf8->relaxed;
         return $decoder->decode( $content );
     }
-
-    eval { require JSON::Syck; };
-    unless( $@ ) {
-        return JSON::Syck::Load( $content );
+    elsif ( eval { require JSON::Syck } ) {
+        require Encode;
+        return JSON::Syck::Load( Encode::decode('UTF-8', $content ) );
     }
-
-    eval { require JSON::PP; JSON::PP->VERSION( 2 ); };
-    unless( $@ ) {
-        my $decoder = JSON::PP->new->relaxed;
+    elsif ( eval { require JSON::PP; JSON::PP->VERSION( 2 ); } ) {
+        my $decoder = JSON::PP->new->utf8->relaxed;
         return $decoder->decode( $content );
     }
-
     require JSON;
-    eval { JSON->VERSION( 2 ); };
-    return $@ ? JSON::jsonToObj( $content ) : JSON::from_json( $content );
+    if ( eval { JSON->VERSION( 2 ) } ) {
+        return JSON::decode_json( $content );
+    }
+    else {
+        return JSON::jsonToObj( $content );
+    }
 }
 
 =head2 requires_any_of( )
