@@ -45,13 +45,10 @@ sub load {
     my $class = shift;
     my $file  = shift;
 
-    eval { require YAML::XS };
-    unless ( $@ ) {
+    if (eval { require YAML::XS; 1 }) {
         return YAML::XS::LoadFile( $file );
     }
-
-    eval { require YAML::Syck; YAML::Syck->VERSION( '0.70' ) };
-    unless ( $@ ) {
+    elsif ($] > 5.008008 && eval { require YAML::Syck; YAML::Syck->VERSION(0.70) } ) {
         open( my $fh, $file ) or die $!;
         my $content = do { local $/; <$fh> };
         close $fh;
@@ -69,7 +66,9 @@ L<YAML> in order to work.
 
 =cut
 
-sub requires_any_of { 'YAML::XS', [ 'YAML::Syck', '0.70' ], 'YAML' }
+sub requires_any_of {
+    'YAML::XS', ( $] > 5.008008 ? [ 'YAML::Syck', '0.70' ] : ()), 'YAML';
+}
 
 =head1 AUTHOR
 
